==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebToggleViewCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableBrowserEventArgsDetailDescriptionMetadata } from "./WebCancelableBrowserEventArgsDetailDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDetailDescription } from "./WebToggleViewCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebToggleViewCancelableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleViewCancelableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a == null) {
                WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleViewCancelableEventArgsDetailDescriptionMetadata.c(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableBrowserEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ToggleViewCancelableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebToggleViewCancelableEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebToggleViewCancelableEventArgsDetail", () => new WebToggleViewCancelableEventArgsDetailDescription());
            a.ac("WebToggleViewCancelableEventArgsDetail", WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToggleViewCancelableEventArgsDetailDescriptionMetadata, 'WebToggleViewCancelableEventArgsDetailDescriptionMetadata');
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebToggleViewCancelableEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebToggleViewCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewCancelableEventArgsDetailDescription } from "./WebToggleViewCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebToggleViewCancelableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleViewCancelableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a == null) {
                WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleViewCancelableEventArgsDetailDescriptionMetadata.c(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ToggleViewCancelableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Id", "String");
        }
        static d(a) {
            WebToggleViewCancelableEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebToggleViewCancelableEventArgsDetail", () => new WebToggleViewCancelableEventArgsDetailDescription());
            a.ad("WebToggleViewCancelableEventArgsDetail", WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToggleViewCancelableEventArgsDetailDescriptionMetadata, 'WebToggleViewCancelableEventArgsDetailDescriptionMetadata');
    WebToggleViewCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebToggleViewCancelableEventArgsDetailDescriptionMetadata;
})();
